from PyQt5 import QtWidgets
from sklearn.linear_model.coordinate_descent import Lasso

from point_spectra_gui.ui.Lasso import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Lasso, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.alphaDoubleSpinBox.setValue(self.alpha)
        self.fitInterceptCheckBox.setChecked(self.fit_intercept)
        self.maxNumOfIterationsSpinBox.setValue(self.max_iter)
        self.toleranceDoubleSpinBox.setValue(self.tol)
        self.forcePositiveCoefficientsCheckBox.setChecked(self.positive)

    def function(self):
        params = {'alpha': self.alphaDoubleSpinBox.value(),
                  'fit_intercept': self.fitInterceptCheckBox.isChecked(),
                  'max_iter': int(self.maxNumOfIterationsSpinBox.value()),
                  'tol': self.toleranceDoubleSpinBox.value(),
                  'positive': self.forcePositiveCoefficientsCheckBox.isChecked(),
                  'selection': 'random',
                  'CV': self.optimizeWCrossValidaitonCheckBox.isChecked()}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.ui.StratifiedFolds import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class StratifiedFolds(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.nFoldsSpinBox.setValue(2)
        self.testFoldsSpinBox.setValue(2)
        self.setComboBox(self.chooseDataToStratifyComboBox, self.datakeys)
        try:  # Some instances where perhaps there is no data to load
            data = self.data[self.chooseDataToStratifyComboBox.currentText()].df['comp'].columns.values
            self.setComboBox(self.chooseVarComboBox, data)
        except:
            pass
        self.chooseDataToStratifyComboBox.activated[int].connect(self.strat_fold_change_vars)
        self.nFoldsSpinBox.valueChanged.connect(self.strat_fold_change_testfolds)

    def function(self):
        datakey = self.chooseDataToStratifyComboBox.currentText()
        nfolds = self.nFoldsSpinBox.value()
        try:
            testfold = int(self.testFoldsSpinBox.value())
        except:
            testfold = 1
        colname = ('comp', self.chooseVarComboBox.currentText())
        self.data[datakey].stratified_folds(nfolds=nfolds, sortby=colname)

        self.data[datakey + '-Train'] = self.data[datakey].rows_match(('meta', 'Folds'), [testfold], invert=True)
        self.data[datakey + '-Test'] = self.data[datakey].rows_match(('meta', 'Folds'), [testfold])
        self.datakeys.append(datakey + '-Train')
        self.datakeys.append(datakey + '-Test')

        print(self.data.keys())
        print(self.data[datakey + '-Test'].df.index.shape)
        print(self.data[datakey + '-Train'].df.index.shape)

    def strat_fold_change_vars(self):
        self.chooseVarComboBox.clear()
        try:
            choices = self.data[self.chooseDataToStratifyComboBox.currentText()].df['comp'].columns.values
        except:
            choices = ['No composition columns!']

        self.chooseVarComboBox.addItems(choices)

    def strat_fold_change_testfolds(self):
        self.testFoldsSpinBox.clear()
        self.testFoldsSpinBox.setMaximum(self.nFoldsSpinBox.value())


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = StratifiedFolds()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout_2.addWidget(self.chooseDataLabel, 0, 0, 1, 1)
        self.figureNameLabel = QtWidgets.QLabel(self.groupBox)
        self.figureNameLabel.setObjectName("figureNameLabel")
        self.gridLayout_2.addWidget(self.figureNameLabel, 1, 0, 1, 1)
        self.plotTitleLabel = QtWidgets.QLabel(self.groupBox)
        self.plotTitleLabel.setObjectName("plotTitleLabel")
        self.gridLayout_2.addWidget(self.plotTitleLabel, 2, 0, 1, 1)
        self.xVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.xVariableLabel.setObjectName("xVariableLabel")
        self.gridLayout_2.addWidget(self.xVariableLabel, 3, 0, 1, 1)
        self.chooseColumnLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseColumnLabel.setObjectName("chooseColumnLabel")
        self.gridLayout_2.addWidget(self.chooseColumnLabel, 4, 0, 1, 1)
        self.chooseRowsLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseRowsLabel.setObjectName("chooseRowsLabel")
        self.gridLayout_2.addWidget(self.chooseRowsLabel, 5, 0, 1, 1)
        self.colorLabel = QtWidgets.QLabel(self.groupBox)
        self.colorLabel.setObjectName("colorLabel")
        self.gridLayout_2.addWidget(self.colorLabel, 7, 0, 1, 1)
        self.lineLabel = QtWidgets.QLabel(self.groupBox)
        self.lineLabel.setObjectName("lineLabel")
        self.gridLayout_2.addWidget(self.lineLabel, 8, 0, 1, 1)
        self.alphaLabel = QtWidgets.QLabel(self.groupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.gridLayout_2.addWidget(self.alphaLabel, 9, 0, 1, 1)
        self.lineWidthLabel = QtWidgets.QLabel(self.groupBox)
        self.lineWidthLabel.setObjectName("lineWidthLabel")
        self.gridLayout_2.addWidget(self.lineWidthLabel, 10, 0, 1, 1)
        self.plotFilenameLabel = QtWidgets.QLabel(self.groupBox)
        self.plotFilenameLabel.setObjectName("plotFilenameLabel")
        self.gridLayout_2.addWidget(self.plotFilenameLabel, 11, 0, 1, 1)
        self.plotFilenameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotFilenameLineEdit.setReadOnly(True)
        self.plotFilenameLineEdit.setObjectName("plotFilenameLineEdit")
        self.gridLayout_2.addWidget(self.plotFilenameLineEdit, 11, 1, 1, 1)
        self.pushButton = QtWidgets.QPushButton(self.groupBox)
        self.pushButton.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.gridLayout_2.addWidget(self.pushButton, 11, 2, 1, 1)
        self.figureNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.figureNameLineEdit.setObjectName("figureNameLineEdit")
        self.gridLayout_2.addWidget(self.figureNameLineEdit, 1, 1, 1, 2)
        self.plotTitleLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotTitleLineEdit.setObjectName("plotTitleLineEdit")
        self.gridLayout_2.addWidget(self.plotTitleLineEdit, 2, 1, 1, 2)
        self.chooseColumnComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseColumnComboBox.setObjectName("chooseColumnComboBox")
        self.gridLayout_2.addWidget(self.chooseColumnComboBox, 4, 1, 1, 2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.minLabel = QtWidgets.QLabel(self.groupBox)
        self.minLabel.setObjectName("minLabel")
        self.horizontalLayout.addWidget(self.minLabel)
        self.minDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minDoubleSpinBox.setObjectName("minDoubleSpinBox")
        self.horizontalLayout.addWidget(self.minDoubleSpinBox)
        self.maxLabel = QtWidgets.QLabel(self.groupBox)
        self.maxLabel.setObjectName("maxLabel")
        self.horizontalLayout.addWidget(self.maxLabel)
        self.maxDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxDoubleSpinBox.setObjectName("maxDoubleSpinBox")
        self.horizontalLayout.addWidget(self.maxDoubleSpinBox)
        self.gridLayout_2.addLayout(self.horizontalLayout, 6, 0, 1, 3)
        self.colorComboBox = QtWidgets.QComboBox(self.groupBox)
        self.colorComboBox.setObjectName("colorComboBox")
        self.gridLayout_2.addWidget(self.colorComboBox, 7, 1, 1, 2)
        self.lineComboBox = QtWidgets.QComboBox(self.groupBox)
        self.lineComboBox.setObjectName("lineComboBox")
        self.gridLayout_2.addWidget(self.lineComboBox, 8, 1, 1, 2)
        self.alphaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.alphaDoubleSpinBox.setObjectName("alphaDoubleSpinBox")
        self.gridLayout_2.addWidget(self.alphaDoubleSpinBox, 9, 1, 1, 2)
        self.lineWidthDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.lineWidthDoubleSpinBox.setObjectName("lineWidthDoubleSpinBox")
        self.gridLayout_2.addWidget(self.lineWidthDoubleSpinBox, 10, 1, 1, 2)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.gridLayout_2.addWidget(self.chooseDataComboBox, 0, 1, 1, 2)
        self.chooseRowsListWidget = QtWidgets.QListWidget(self.groupBox)
        self.chooseRowsListWidget.setObjectName("chooseRowsListWidget")
        self.gridLayout_2.addWidget(self.chooseRowsListWidget, 5, 1, 1, 2)
        self.xVariableListWidget = QtWidgets.QListWidget(self.groupBox)
        self.xVariableListWidget.setObjectName("xVariableListWidget")
        self.gridLayout_2.addWidget(self.xVariableListWidget, 3, 1, 1, 2)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.chooseDataComboBox, self.figureNameLineEdit)
        Form.setTabOrder(self.figureNameLineEdit, self.plotTitleLineEdit)
        Form.setTabOrder(self.plotTitleLineEdit, self.xVariableListWidget)
        Form.setTabOrder(self.xVariableListWidget, self.chooseColumnComboBox)
        Form.setTabOrder(self.chooseColumnComboBox, self.chooseRowsListWidget)
        Form.setTabOrder(self.chooseRowsListWidget, self.minDoubleSpinBox)
        Form.setTabOrder(self.minDoubleSpinBox, self.maxDoubleSpinBox)
        Form.setTabOrder(self.maxDoubleSpinBox, self.colorComboBox)
        Form.setTabOrder(self.colorComboBox, self.lineComboBox)
        Form.setTabOrder(self.lineComboBox, self.alphaDoubleSpinBox)
        Form.setTabOrder(self.alphaDoubleSpinBox, self.lineWidthDoubleSpinBox)
        Form.setTabOrder(self.lineWidthDoubleSpinBox, self.plotFilenameLineEdit)
        Form.setTabOrder(self.plotFilenameLineEdit, self.pushButton)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Plot Spectra"))
        self.chooseDataLabel.setText(("Choose Data"))
        self.figureNameLabel.setText(("Figure Name"))
        self.plotTitleLabel.setText(("Plot Title"))
        self.xVariableLabel.setText(("X Variable:"))
        self.chooseColumnLabel.setText(("Choose Column"))
        self.chooseRowsLabel.setText(("Choose Rows:"))
        self.colorLabel.setText(("Color"))
        self.lineLabel.setText(("Line"))
        self.alphaLabel.setText(("Alpha"))
        self.lineWidthLabel.setText(("Line width"))
        self.plotFilenameLabel.setText(("Plot Filename"))
        self.pushButton.setText(("..."))
        self.minLabel.setText(("Min"))
        self.maxLabel.setText(("Max"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import numpy as np
from PyQt5 import QtWidgets

from point_spectra_gui.ui.PeakAreas import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class PeakAreas(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.peakMinimaLineEdit.setText("None (calculate from average spectrum)")
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.pushButton.clicked.connect(lambda: self.on_getDataButton_clicked(self.peakMinimaLineEdit))

    def function(self):
        datakey = self.chooseDataComboBox.currentText()
        peaks_mins_file = self.peakMinimaLineEdit.text()
        if peaks_mins_file == "None (calculate from average spectrum)":
            peaks_mins_file = None

        try:
            peaks, mins = self.data[datakey].peak_area(peaks_mins_file=peaks_mins_file)
            print("Peak Areas Calculated")

            np.savetxt(self.outpath + '/peaks.csv', peaks, delimiter=',')
            np.savetxt(self.outpath + '/mins.csv', mins, delimiter=',')

        except Exception as e:
            print(e)

    def on_getDataButton_clicked(self, lineEdit):
        filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None, "Open peaks and minima File", '.', "(*.csv)")
        lineEdit.setText(filename)
        if lineEdit.text() == "":
            lineEdit.setText("None (calculate from average spectrum)")


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = PeakAreas()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_loadData(object):
    def setupUi(self, loadData):
        loadData.setObjectName("loadData")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(loadData.sizePolicy().hasHeightForWidth())
        loadData.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(loadData)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(loadData)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.fileNameLabel = QtWidgets.QLabel(self.groupBox)
        self.fileNameLabel.setObjectName("fileNameLabel")
        self.gridLayout.addWidget(self.fileNameLabel, 0, 0, 1, 1)
        self.fileNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.fileNameLineEdit.setObjectName("fileNameLineEdit")
        self.gridLayout.addWidget(self.fileNameLineEdit, 0, 1, 1, 1)
        self.newFilePushButton = QtWidgets.QPushButton(self.groupBox)
        self.newFilePushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.newFilePushButton.setObjectName("newFilePushButton")
        self.gridLayout.addWidget(self.newFilePushButton, 0, 2, 1, 1)
        self.dataSetNameLabel = QtWidgets.QLabel(self.groupBox)
        self.dataSetNameLabel.setObjectName("dataSetNameLabel")
        self.gridLayout.addWidget(self.dataSetNameLabel, 1, 0, 1, 1)
        self.dataSetNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.dataSetNameLineEdit.setObjectName("dataSetNameLineEdit")
        self.gridLayout.addWidget(self.dataSetNameLineEdit, 1, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(loadData)
        QtCore.QMetaObject.connectSlotsByName(loadData)

    def retranslateUi(self, loadData):
        _translate = QtCore.QCoreApplication.translate
        loadData.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Load Data"))
        self.fileNameLabel.setText(("File Name"))
        self.fileNameLineEdit.setText(("*.csv"))
        self.newFilePushButton.setToolTip(("<html><head/><body><p>Press this to select a file</p></body></html>"))
        self.newFilePushButton.setText(("..."))
        self.dataSetNameLabel.setText(("Data Set Name"))
        self.dataSetNameLineEdit.setToolTip(("<html><head/><body><p>Give your dataset a name</p></body></html>"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    loadData = QtWidgets.QWidget()
    ui = Ui_loadData()
    ui.setupUi(loadData)
    loadData.show()
    sys.exit(app.exec_())




import numpy as np
import pandas as pd
from PyQt5 import QtWidgets
from Qtickle import Qtickle
from pysat.regression import regression
from pysat.spectral.spectral_data import spectral_data
from point_spectra_gui.core.regressionMethods import *
from point_spectra_gui.ui.RegressionTrain import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics



class RegressionTrain(Ui_Form, Basics):
    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Basics.setupUi(self, Form)
        self.regressionMethods()

    def get_widget(self):
        return self.groupLayout

    def make_regression_widget(self, alg, params=None):
        self.hideAll()
        print(alg)
        for i in range(len(self.algorithm_list) - 1):
            if alg == self.algorithm_list[i] and i > 0:
                self.alg[i - 1].setHidden(False)

    def connectWidgets(self):
        self.algorithm_list = ['Choose an algorithm',
                               'PLS',
                               'OLS',
                               'OMP',
                               'Lasso',
                               'Elastic Net',
                               'Ridge',
                               'Bayesian Ridge',
                               'ARD',
                               'LARS',
                               'Lasso LARS',
                               'SVR',
                               'KRR',
                               'More to come...']
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseAlgorithmComboBox, self.algorithm_list)
        self.yMaxDoubleSpinBox.setMaximum(999999)
        self.yMinDoubleSpinBox.setMaximum(999999)
        self.yMaxDoubleSpinBox.setValue(100)
        self.changeComboListVars(self.yVariableList, self.yvar_choices())
        self.changeComboListVars(self.xVariableList, self.xvar_choices())
        self.xvar_choices()
        self.chooseAlgorithmComboBox.currentIndexChanged.connect(
            lambda: self.make_regression_widget(self.chooseAlgorithmComboBox.currentText()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.yVariableList, self.yvar_choices()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.xVariableList, self.xvar_choices()))

    def getGuiParams(self):
        """
        Overriding Basics' getGuiParams, because I'll need to do a list of lists
        in order to obtain the regressionMethods' parameters
        """
        self.qt = Qtickle.Qtickle(self)
        s = []
        s.append(self.qt.guiSave())
        for items in self.alg:
            s.append(items.getGuiParams())
        return s

    def setGuiParams(self, dict):
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict[0])
        for i in range(len(dict)):
            self.alg[i - 1].setGuiParams(dict[i])

    def function(self):
        method = self.chooseAlgorithmComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()
        xvars = [str(x.text()) for x in self.xVariableList.selectedItems()]
        yvars = [('comp', str(y.text())) for y in self.yVariableList.selectedItems()]
        yrange = [self.yMinDoubleSpinBox.value(), self.yMaxDoubleSpinBox.value()]

        params, modelkey = self.getMethodParams(self.chooseAlgorithmComboBox.currentIndex())
        # try:
        modelkey = "{} - {} - ({}, {}) {}".format(method, yvars[0][-1], yrange[0], yrange[1], params)
        self.modelkeys.append(modelkey)
        print(params, modelkey)
        self.models[modelkey] = regression.regression([method], [yrange], [params])
        x = self.data[datakey].df[xvars]
        y = self.data[datakey].df[yvars]
        x = np.array(x)
        y = np.array(y)
        ymask = np.squeeze((y > yrange[0]) & (y < yrange[1]))
        y = y[ymask]
        x = x[ymask, :]
        self.models[modelkey].fit(x, y)
        self.model_xvars[modelkey] = xvars
        self.model_yvars[modelkey] = yvars
        coef = np.squeeze(self.models[modelkey].model.coef_)
        coef = pd.DataFrame(coef)
        coef.index = pd.MultiIndex.from_tuples(self.data[datakey].df[xvars].columns.values)
        coef = coef.T
        coef[('meta', 'Model')] = modelkey

        try:
            self.data['Model Coefficients'] = spectral_data(pd.concat([self.data['Model Coefficients'].df, coef]))
        except:
            self.data['Model Coefficients'] = spectral_data(coef)
            self.datakeys.append('Model Coefficients')

    def yvar_choices(self):
        try:
            yvarchoices = self.data[self.chooseDataComboBox.currentText()].df['comp'].columns.values
            yvarchoices = [i for i in yvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            yvarchoices = ['No composition columns!']
        return yvarchoices

    def xvar_choices(self):
        try:
            xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[0].values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices

    def hideAll(self):
        for a in self.alg:
            a.setHidden(True)

    def getMethodParams(self, index):
        return self.alg[index - 1].function()

    def regressionMethods(self):
        self.alg = []
        list_forms = [PLS,
                      OLS,
                      OMP,
                      Lasso,
                      ElasticNet,
                      Ridge,
                      BayesianRidge,
                      ARD,
                      LARS,
                      LassoLARS,
                      SVR,
                      KRR]
        for items in list_forms:
            self.alg.append(items.Ui_Form())
            self.alg[-1].setupUi(self.Form)
            self.algorithmLayout.addWidget(self.alg[-1].get_widget())
            self.alg[-1].setHidden(True)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = RegressionTrain()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from point_spectra_gui.core.regressionMethods import ARD
from point_spectra_gui.core.regressionMethods import BayesianRidge
from point_spectra_gui.core.regressionMethods import ElasticNet
from point_spectra_gui.core.regressionMethods import GP
from point_spectra_gui.core.regressionMethods import KRR
from point_spectra_gui.core.regressionMethods import LARS
from point_spectra_gui.core.regressionMethods import Lasso
from point_spectra_gui.core.regressionMethods import LassoLARS
from point_spectra_gui.core.regressionMethods import OLS
from point_spectra_gui.core.regressionMethods import OMP
from point_spectra_gui.core.regressionMethods import PLS
from point_spectra_gui.core.regressionMethods import Ridge
from point_spectra_gui.core.regressionMethods import SVR



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.Ridge_CV = QtWidgets.QGroupBox(self.groupBox)
        self.Ridge_CV.setObjectName("Ridge_CV")
        self.formLayout_6 = QtWidgets.QFormLayout(self.Ridge_CV)
        self.formLayout_6.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_6.setObjectName("formLayout_6")
        self.alphasLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.alphasLabel_cv.setObjectName("alphasLabel_cv")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.alphasLabel_cv)
        self.alphasLineEdit_cv = QtWidgets.QLineEdit(self.Ridge_CV)
        self.alphasLineEdit_cv.setObjectName("alphasLineEdit_cv")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.alphasLineEdit_cv)
        self.fitInterceptLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.fitInterceptLabel_cv.setObjectName("fitInterceptLabel_cv")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel_cv)
        self.fitInterceptCheckBox_cv = QtWidgets.QCheckBox(self.Ridge_CV)
        self.fitInterceptCheckBox_cv.setChecked(True)
        self.fitInterceptCheckBox_cv.setObjectName("fitInterceptCheckBox_cv")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox_cv)
        self.normalizeLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.normalizeLabel_cv.setObjectName("normalizeLabel_cv")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel_cv)
        self.normalizeCheckBox_cv = QtWidgets.QCheckBox(self.Ridge_CV)
        self.normalizeCheckBox_cv.setObjectName("normalizeCheckBox_cv")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox_cv)
        self.scoringLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.scoringLabel_cv.setObjectName("scoringLabel_cv")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.scoringLabel_cv)
        self.scoringComboBox_cv = QtWidgets.QComboBox(self.Ridge_CV)
        self.scoringComboBox_cv.setObjectName("scoringComboBox_cv")
        self.scoringComboBox_cv.addItem("")
        self.scoringComboBox_cv.addItem("")
        self.scoringComboBox_cv.addItem("")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.scoringComboBox_cv)
        self.gCVModeLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.gCVModeLabel_cv.setObjectName("gCVModeLabel_cv")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.gCVModeLabel_cv)
        self.gCVModeComboBox_cv = QtWidgets.QComboBox(self.Ridge_CV)
        self.gCVModeComboBox_cv.setObjectName("gCVModeComboBox_cv")
        self.gCVModeComboBox_cv.addItem("")
        self.gCVModeComboBox_cv.addItem("")
        self.gCVModeComboBox_cv.addItem("")
        self.gCVModeComboBox_cv.addItem("")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.gCVModeComboBox_cv)
        self.storeCVValuesLabel_cv = QtWidgets.QLabel(self.Ridge_CV)
        self.storeCVValuesLabel_cv.setObjectName("storeCVValuesLabel_cv")
        self.formLayout_6.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.storeCVValuesLabel_cv)
        self.storeCVValuesCheckBox_cv = QtWidgets.QCheckBox(self.Ridge_CV)
        self.storeCVValuesCheckBox_cv.setObjectName("storeCVValuesCheckBox_cv")
        self.formLayout_6.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.storeCVValuesCheckBox_cv)
        self.horizontalLayout.addWidget(self.Ridge_CV)
        self.Ridge = QtWidgets.QGroupBox(self.groupBox)
        self.Ridge.setEnabled(True)
        self.Ridge.setObjectName("Ridge")
        self.formLayout_2 = QtWidgets.QFormLayout(self.Ridge)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.alphaLabel = QtWidgets.QLabel(self.Ridge)
        self.alphaLabel.setObjectName("alphaLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.alphaLabel)
        self.alphaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.Ridge)
        self.alphaDoubleSpinBox.setProperty("value", 1.0)
        self.alphaDoubleSpinBox.setObjectName("alphaDoubleSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.alphaDoubleSpinBox)
        self.copyXLabel = QtWidgets.QLabel(self.Ridge)
        self.copyXLabel.setObjectName("copyXLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.copyXLabel)
        self.copyXCheckBox = QtWidgets.QCheckBox(self.Ridge)
        self.copyXCheckBox.setChecked(True)
        self.copyXCheckBox.setObjectName("copyXCheckBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.copyXCheckBox)
        self.fitInterceptLabel = QtWidgets.QLabel(self.Ridge)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.Ridge)
        self.fitInterceptCheckBox.setChecked(True)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.maxNumOfIterationsLabel = QtWidgets.QLabel(self.Ridge)
        self.maxNumOfIterationsLabel.setObjectName("maxNumOfIterationsLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.maxNumOfIterationsLabel)
        self.maxNumOfIterationslineEdit = QtWidgets.QLineEdit(self.Ridge)
        self.maxNumOfIterationslineEdit.setObjectName("maxNumOfIterationslineEdit")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.maxNumOfIterationslineEdit)
        self.normalizeLabel = QtWidgets.QLabel(self.Ridge)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.Ridge)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.solverLabel = QtWidgets.QLabel(self.Ridge)
        self.solverLabel.setObjectName("solverLabel")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.solverLabel)
        self.solverComboBox = QtWidgets.QComboBox(self.Ridge)
        self.solverComboBox.setObjectName("solverComboBox")
        self.solverComboBox.addItem("")
        self.solverComboBox.addItem("")
        self.solverComboBox.addItem("")
        self.solverComboBox.addItem("")
        self.solverComboBox.addItem("")
        self.solverComboBox.addItem("")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.solverComboBox)
        self.toleranceLabel = QtWidgets.QLabel(self.Ridge)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout_2.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.Ridge)
        self.toleranceDoubleSpinBox.setObjectName("toleranceDoubleSpinBox")
        self.formLayout_2.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.toleranceDoubleSpinBox)
        self.randomStateLabel = QtWidgets.QLabel(self.Ridge)
        self.randomStateLabel.setObjectName("randomStateLabel")
        self.formLayout_2.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.randomStateLabel)
        self.randomStateLineEdit = QtWidgets.QLineEdit(self.Ridge)
        self.randomStateLineEdit.setObjectName("randomStateLineEdit")
        self.formLayout_2.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.randomStateLineEdit)
        self.horizontalLayout.addWidget(self.Ridge)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.formGroupBox_2 = QtWidgets.QGroupBox(self.groupBox)
        self.formGroupBox_2.setObjectName("formGroupBox_2")
        self.formLayout_5 = QtWidgets.QFormLayout(self.formGroupBox_2)
        self.formLayout_5.setObjectName("formLayout_5")
        self.crossValidateLabel = QtWidgets.QLabel(self.formGroupBox_2)
        self.crossValidateLabel.setObjectName("crossValidateLabel")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.crossValidateLabel)
        self.crossValidateCheckBox = QtWidgets.QCheckBox(self.formGroupBox_2)
        self.crossValidateCheckBox.setChecked(True)
        self.crossValidateCheckBox.setObjectName("crossValidateCheckBox")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.crossValidateCheckBox)
        self.verticalLayout.addWidget(self.formGroupBox_2)
        self.verticalLayout_2.addWidget(self.groupBox)

        self.retranslateUi(Form)
        self.crossValidateCheckBox.toggled['bool'].connect(self.Ridge_CV.setVisible)
        self.crossValidateCheckBox.toggled['bool'].connect(self.Ridge.setHidden)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.Ridge_CV.setTitle(("Ridge CV"))
        self.alphasLabel_cv.setText(("alphas"))
        self.alphasLineEdit_cv.setText(("0.1, 1.0, 10.0"))
        self.fitInterceptLabel_cv.setText(("Fit intercept "))
        self.normalizeLabel_cv.setText(("Normalize "))
        self.scoringLabel_cv.setText(("Scoring"))
        self.scoringComboBox_cv.setItemText(0, ("None"))
        self.scoringComboBox_cv.setItemText(1, ("string"))
        self.scoringComboBox_cv.setItemText(2, ("callable"))
        self.gCVModeLabel_cv.setText(("GCV mode"))
        self.gCVModeComboBox_cv.setItemText(0, ("None"))
        self.gCVModeComboBox_cv.setItemText(1, ("auto"))
        self.gCVModeComboBox_cv.setItemText(2, ("svd"))
        self.gCVModeComboBox_cv.setItemText(3, ("eigen"))
        self.storeCVValuesLabel_cv.setText(("Store CV Values           "))
        self.Ridge.setTitle(("Ridge"))
        self.alphaLabel.setText(("Alpha"))
        self.copyXLabel.setText(("Copy X"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.maxNumOfIterationsLabel.setText(("Max num of Iterations"))
        self.maxNumOfIterationslineEdit.setText(("None"))
        self.normalizeLabel.setText(("Normalize"))
        self.solverLabel.setText(("Solver"))
        self.solverComboBox.setItemText(0, ("auto"))
        self.solverComboBox.setItemText(1, ("svd"))
        self.solverComboBox.setItemText(2, ("cholesky"))
        self.solverComboBox.setItemText(3, ("lsqr"))
        self.solverComboBox.setItemText(4, ("sparse_cg"))
        self.solverComboBox.setItemText(5, ("sag"))
        self.toleranceLabel.setText(("Tolerance"))
        self.randomStateLabel.setText(("Random State"))
        self.randomStateLineEdit.setText(("None"))
        self.crossValidateLabel.setText(("Cross Validate              "))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import ast

from PyQt5 import QtWidgets
from sklearn.linear_model.ridge import Ridge
from sklearn.linear_model.ridge import RidgeCV

from point_spectra_gui.ui.Ridge import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Ridge, RidgeCV, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.Ridge.setVisible(False)
        ridgecv = RidgeCV()

        self.alphasLineEdit_cv.setText(str(ridgecv.alphas))
        self.fitInterceptCheckBox_cv.setChecked(ridgecv.fit_intercept)
        self.normalizeCheckBox_cv.setChecked(ridgecv.normalize)
        self.defaultComboItem(self.scoringComboBox_cv, ridgecv.scoring)
        self.defaultComboItem(self.gCVModeComboBox_cv, ridgecv.gcv_mode)
        self.storeCVValuesCheckBox_cv.setChecked(ridgecv.store_cv_values)

        ridge = Ridge()

        self.alphaDoubleSpinBox.setValue(ridge.alpha)
        self.fitInterceptCheckBox.setChecked(ridge.fit_intercept)
        self.normalizeCheckBox.setChecked(ridge.normalize)
        self.copyXCheckBox.setChecked(ridge.copy_X)
        self.defaultComboItem(self.solverComboBox, ridge.solver)
        self.toleranceDoubleSpinBox.setValue(ridge.tol)
        self.randomStateLineEdit.setText(str(ridge.random_state))

    def function(self):
        m_attrib = {'None': None}
        r_attrib = {'None': None}
        try:
            m_state = int(self.maxNumOfIterationslineEdit.text())
        except:
            m_state = m_attrib[self.maxNumOfIterationslineEdit.text()]
        try:
            r_state = int(self.randomStateLineEdit.text())
        except:
            r_state = r_attrib[self.randomStateLineEdit.text()]

        if self.crossValidateCheckBox.isChecked():
            params = {'alphas': ast.literal_eval(self.alphasLineEdit_cv.text()),
                      'fit_intercept': self.fitInterceptCheckBox_cv.isChecked(),
                      'normalize': self.normalizeCheckBox_cv.isChecked(),
                      'scoring': {'None': None}.get(self.scoringComboBox_cv.currentText()),
                      'gcv_mode': {'None': None}.get(self.gCVModeComboBox_cv.currentText()),
                      'store_cv_values': self.storeCVValuesCheckBox_cv.isChecked(),
                      'CV': self.crossValidateCheckBox.isChecked()}
        else:
            params = {'alpha': self.alphaDoubleSpinBox.value(),
                      'copy_X': self.copyXCheckBox.isChecked(),
                      'fit_intercept': self.fitInterceptCheckBox.isChecked(),
                      'max_iter': m_state,
                      'normalize': self.normalizeCheckBox.isChecked(),
                      'solver': self.solverComboBox.currentText(),
                      'tol': self.toleranceDoubleSpinBox.value(),
                      'random_state': r_state,
                      'CV': self.crossValidateCheckBox.isChecked()}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import pandas as pd
from PyQt5 import QtWidgets
from pysat.fileio import io_ccam_pds
from pysat.spectral.spectral_data import spectral_data

from point_spectra_gui.ui.ReadChemCamData import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class ReadChemCamData(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.searchStringLineEdit.setText("*ccs*.csv")
        self.searchDirectorypushButton.clicked.connect(self.on_searchpathButton_clicked)
        self.metadatapushButton.clicked.connect(self.on_metadataButton_clicked)

    def on_searchpathButton_clicked(self):
        dirname = QtWidgets.QFileDialog.getExistingDirectory(parent=None, caption="Select Search Directory",
                                                             directory='.')
        self.searchDirectoryLineEdit.setText(dirname)
        if self.searchDirectoryLineEdit.text() == "":
            self.searchDirectoryLineEdit.setText("*/")

    def on_metadataButton_clicked(self):
        self.metadata_file, null = QtWidgets.QFileDialog.getOpenFileNames(parent=None,
                                                                          caption="Select metadata file(s)",
                                                                          directory='.')
        self.metadataFilesLineEdit.setText(str(self.metadata_file))
        if self.metadataFilesLineEdit.text() == "":
            self.metadataFilesLineEdit.setText("*/")

    def function(self):
        params = self.getGuiParams()
        searchdir = params['searchDirectoryLineEdit']
        searchstring = params['searchStringLineEdit']
        to_csv = params['outputFileNameLineEdit']
        try:
            lookupfile = params['metadataFilesLineEdit']
        except:
            lookupfile = None
        ave = bool(params['averagesradioButton'])
        progressbar = QtWidgets.QProgressDialog()
        io_ccam_pds.ccam_batch(searchdir, searchstring=searchstring, to_csv=Basics.outpath + '/' + to_csv,
                               lookupfile=lookupfile, ave=ave, progressbar=progressbar)
        self.do_get_data(Basics.outpath + '/' + to_csv, 'ChemCam')

    def do_get_data(self, filename, keyname):
        try:
            print('Loading data file: ' + str(filename))
            self.data[keyname] = spectral_data(pd.read_csv(filename, header=[0, 1]))
            self.datakeys.append(keyname)
            pass
        except Exception as e:
            print('Problem reading data: {}'.format(e))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    
    Form = QtWidgets.QWidget()
    ui = ReadChemCamData()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.formGroupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout.addWidget(self.chooseDataLabel, 0, 0, 1, 1)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.gridLayout.addWidget(self.chooseDataComboBox, 0, 1, 1, 1)
        self.chooseAlgorithmLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseAlgorithmLabel.setObjectName("chooseAlgorithmLabel")
        self.gridLayout.addWidget(self.chooseAlgorithmLabel, 1, 0, 1, 1)
        self.chooseAlgorithmComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseAlgorithmComboBox.setObjectName("chooseAlgorithmComboBox")
        self.gridLayout.addWidget(self.chooseAlgorithmComboBox, 1, 1, 1, 1)
        self.algorithmLayout = QtWidgets.QVBoxLayout()
        self.algorithmLayout.setObjectName("algorithmLayout")
        self.gridLayout.addLayout(self.algorithmLayout, 2, 0, 1, 2)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("Baseline Removal"))
        self.chooseDataLabel.setText(("Choose data"))
        self.chooseAlgorithmLabel.setText(("Choose algorithm"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout_2.addWidget(self.chooseDataLabel, 0, 0, 1, 1)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.gridLayout_2.addWidget(self.chooseDataComboBox, 0, 1, 1, 1)
        self.maskFileLabel = QtWidgets.QLabel(self.groupBox)
        self.maskFileLabel.setObjectName("maskFileLabel")
        self.gridLayout_2.addWidget(self.maskFileLabel, 1, 0, 1, 1)
        self.maskFileLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.maskFileLineEdit.setObjectName("maskFileLineEdit")
        self.gridLayout_2.addWidget(self.maskFileLineEdit, 1, 1, 1, 1)
        self.pushButton = QtWidgets.QPushButton(self.groupBox)
        self.pushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.gridLayout_2.addWidget(self.pushButton, 1, 2, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Mask Data"))
        self.chooseDataLabel.setText(("Choose Data:"))
        self.maskFileLabel.setText(("Mask file:"))
        self.maskFileLineEdit.setText(("*.csv"))
        self.pushButton.setText(("..."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.linear_model import ElasticNet
from sklearn.linear_model.coordinate_descent import ElasticNetCV

from point_spectra_gui.ui.ElasticNet import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, ElasticNet, ElasticNetCV, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.elasticNetCVGroupBox.setHidden(True)
        en = ElasticNet()
        encv = ElasticNetCV()

        self.enalphaDoubleSpinBox.setValue(en.alpha)
        self.enl1_ratioDoubleSpinBox.setValue(en.l1_ratio)
        self.enfit_interceptCheckBox.setChecked(en.fit_intercept)
        self.ennormalizeCheckBox.setChecked(en.normalize)
        self.enprecomputeCheckBox.setChecked(en.precompute)
        self.enmax_iterSpinBox.setValue(en.max_iter)
        self.encopy_XCheckBox.setChecked(en.copy_X)
        self.entolDoubleSpinBox.setValue(en.tol)
        self.enwarm_startCheckBox.setChecked(en.warm_start)
        self.enpositiveCheckBox.setChecked(en.positive)
        self.setComboBox(self.enselectionComboBox, ['cyclic', 'random'])
        self.defaultComboItem(self.enselectionComboBox, en.selection)

        self.l1_ratioDoubleSpinBox.setValue(encv.l1_ratio)
        self.epsDoubleSpinBox.setValue(encv.eps)
        self.n_alphasSpinBox.setValue(encv.n_alphas)
        self.alphasLineEdit.setText('None')
        self.fit_interceptCheckBox.setChecked(encv.fit_intercept)
        self.normalizeCheckBox.setChecked(encv.normalize)
        self.setComboBox(self.precomputeComboBox, ['True', 'False', 'auto', 'array-like'])
        self.defaultComboItem(self.precomputeComboBox, encv.precompute)
        self.max_iterSpinBox.setValue(encv.max_iter)
        self.tolDoubleSpinBox.setValue(encv.tol)
        self.cVSpinBox.setValue(3)
        self.copy_XCheckBox.setChecked(encv.copy_X)
        self.verboseCheckBox.setChecked(encv.verbose)
        self.n_jobsSpinBox.setValue(encv.n_jobs)
        self.positiveCheckBox.setChecked(encv.positive)
        self.setComboBox(self.selectionComboBox, ['cyclic', 'random'])
        self.defaultComboItem(self.selectionComboBox, encv.selection)

    def function(self):
        p_attrib = {'False': False, 'True': True, 'Array-like': 'array-like'}
        r_attrib = {'None': None}
        # TODO Add back the random state later.
        # try:
        #     r_state = int(self.randomStateLineEdit.text())
        # except:
        #     r_state = r_attrib[self.randomStateLineEdit.text()]

        index = self.precomputeComboBox.currentIndex()
        precomputeComboBox = self.precomputeComboBox.itemText(index)

        if self.CVCheckBox.isChecked():
            params = {
                'l1_ratio': self.l1_ratioDoubleSpinBox.value(),
                'eps': self.epsDoubleSpinBox.value(),
                'n_alphas': self.n_alphasSpinBox.value(),
                'alphas': {'None': None}.get(self.alphasLineEdit.text()),
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': self.precomputeComboBox.currentText(),
                'max_iter': self.max_iterSpinBox.value(),
                'tol': self.max_iterSpinBox.value(),
                'cv': self.cVSpinBox.value(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'verbose': self.verboseCheckBox.isChecked(),
                'n_jobs': self.n_jobsSpinBox.value(),
                'positive': self.positiveCheckBox.isChecked(),
                'selection': self.selectionComboBox.currentText(),
                'CV': self.CVCheckBox.isChecked()}
        else:
            params = {
                'alpha': self.enalphaDoubleSpinBox.value(),
                'l1_ratio': self.enl1_ratioDoubleSpinBox.value(),
                'fit_intercept': self.enfit_interceptCheckBox.isChecked(),
                'normalize': self.ennormalizeCheckBox.isChecked(),
                'precompute': self.enprecomputeCheckBox.isChecked(),
                'max_iter': self.enmax_iterSpinBox.value(),
                'copy_X': self.encopy_XCheckBox.isChecked(),
                'tol': self.entolDoubleSpinBox.value(),
                'warm_start': self.enwarm_startCheckBox.isChecked(),
                'positive': self.enpositiveCheckBox.isChecked(),
                'selection': self.selectionComboBox.currentText(),
                'CV': self.CVCheckBox.isChecked()}

        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import numpy as np
from PyQt5 import QtWidgets
from pysat.plotting.plots import make_plot

from point_spectra_gui.ui.PlotSpectra import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class PlotSpectra(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.colorComboBox.addItem("Red")
        self.colorComboBox.addItem("Green")
        self.colorComboBox.addItem("Blue")
        self.colorComboBox.addItem("Cyan")
        self.colorComboBox.addItem("Yellow")
        self.colorComboBox.addItem("Magenta")
        self.colorComboBox.addItem("Black")
        self.lineComboBox.addItem("Line")
        self.lineComboBox.addItem("Dashed Line")
        self.lineComboBox.addItem("Dotted Line")
        self.lineComboBox.addItem("Points (No Line)")
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.lineWidthDoubleSpinBox.setRange(0, 10)
        self.lineWidthDoubleSpinBox.setValue(0.5)
        self.lineWidthDoubleSpinBox.setSingleStep(0.05)
        self.alphaDoubleSpinBox.setRange(0, 1)
        self.alphaDoubleSpinBox.setValue(1.0)
        self.alphaDoubleSpinBox.setSingleStep(0.1)
        self.maxDoubleSpinBox.setMaximum(99999)
        self.maxDoubleSpinBox.setMinimum(0)
        self.minDoubleSpinBox.setMaximum(99999)
        self.minDoubleSpinBox.setMinimum(0)
        self.pushButton.clicked.connect(self.on_pushButton_clicked)
        try:
            self.setComboBox(self.chooseDataComboBox, self.datakeys)
            self.setListWidget(self.xVariableListWidget, self.xvar_choices())
            self.plot_spect_change_vars(self.chooseColumnComboBox)
            self.plot_spect_update_list(self.chooseRowsListWidget)
        except Exception as e:
            print("Could not process lists: {}".format(e))

        self.chooseDataComboBox.activated[int].connect(lambda: self.plot_spect_change_vars(self.chooseColumnComboBox))
        self.chooseColumnComboBox.activated[int].connect(lambda: self.plot_spect_update_list(self.chooseRowsListWidget))
        self.chooseDataComboBox.activated[int].connect(lambda: self.plot_spect_update_list(self.chooseRowsListWidget))
        try:
            self.xVariableListWidget.itemSelectionChanged.connect(
                lambda: self.set_spect_minmax(self.minDoubleSpinBox, self.maxDoubleSpinBox,
                                              self.xVariableListWidget.selectedItems()[0].text()))
        except:
            pass

    def function(self):
        yrange = None
        xtitle = 'Wavelength (nm)'
        ytitle = None
        lbl = None
        one_to_one = False
        dpi = 1000
        annot_mask = None
        cmap = None
        colortitle = ''
        marker = None

        datakey = self.chooseDataComboBox.currentText()
        try:
            xcol = self.xVariableListWidget.selectedItems()[0].text()
        except:
            xcol = 'wvl'
        col = self.chooseColumnComboBox.currentText()
        try:
            row = self.chooseRowsListWidget.selectedItems()[0].text()
        except:
            row = 'None Selected'
        figname = self.figureNameLineEdit.text()
        title = self.plotTitleLineEdit.text()
        figfile = self.plotFilenameLineEdit.text()
        figpath, figfile = '/'.join(figfile.split('/')[:-1]), figfile.split('/')[-1]
        color = self.colorComboBox.currentText()
        alpha = self.alphaDoubleSpinBox.value()
        linewidth = self.lineWidthDoubleSpinBox.value()

        if color == 'Red':
            color = [1, 0, 0, alpha]
        elif color == 'Green':
            color = [0, 1, 0, alpha]
        elif color == 'Blue':
            color = [0, 0, 1, alpha]
        elif color == 'Cyan':
            color = [0, 1, 1, alpha]
        elif color == 'Yellow':
            color = [1, 1, 0, alpha]
        elif color == 'Magenta':
            color = [1, 0, 1, alpha]
        elif color == 'Black':
            color = [0, 0, 0, alpha]
        else:
            color = [0, 0, 0, alpha]

        line = self.lineComboBox.currentText()
        if line == 'Points (No Line)':
            linestyle = 'None'
        elif line == 'Line':
            linestyle = '-'
        elif line == 'Dashed Line':
            linestyle = '--'
        elif line == 'Dotted Line':
            linestyle = ':'
        else:
            linestyle = '-'

        xmin = self.minDoubleSpinBox.value()
        xmax = self.maxDoubleSpinBox.value()
        xrange = [xmin, xmax]
        self.data[datakey].enumerate_duplicates(col)
        data = self.data[datakey].df

        y = np.squeeze(np.array(data.loc[data[('meta', col)].isin([row])][xcol].T))
        x = np.array(data[xcol].columns.values)
        if linestyle == 'None':
            marker = 'o'
        try:
            loadfig = self.figs[figname]
        except:
            loadfig = None

        self.figs[figname] = make_plot(x, y, figpath=figpath, figfile=figfile, xrange=xrange, yrange=yrange,
                                       xtitle=xtitle,
                                       ytitle=ytitle, title=title,
                                       lbl=lbl, one_to_one=one_to_one, dpi=dpi, color=color,
                                       annot_mask=annot_mask, cmap=cmap,
                                       colortitle=colortitle, loadfig=loadfig, marker=marker, linestyle=linestyle,
                                       linewidth=linewidth)

    def xvar_choices(self):
        try:
            try:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[0].values
            except:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].columns.values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices

    def plot_spect_change_vars(self, obj):
        obj.clear()
        try:
            self.vars_level0 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = self.vars_level1[self.vars_level0 == 'meta']
            self.vars_level0 = self.vars_level0[self.vars_level0 != 'meta']

            try:
                self.vars_level0 = [i for i in self.vars_level0 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except:
                pass
            try:
                self.vars_level1 = [i for i in self.vars_level1 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except:
                pass
            choices = self.vars_level1

        except:
            try:
                choices = self.data[self.chooseDataComboBox.currentText()].columns.values
            except:
                choices = ['No valid choices']
        for i in choices:
            obj.addItem(str(i))

    def plot_spect_update_list(self, obj):
        try:
            obj.clear()
            self.data[self.chooseDataComboBox.currentText()].enumerate_duplicates(
                self.chooseColumnComboBox.currentText())
            rowchoices = self.data[self.chooseDataComboBox.currentText()].df[
                ('meta', self.chooseColumnComboBox.currentText())]
            for i in rowchoices:
                obj.addItem(i)
        except:
            pass

    def set_spect_minmax(self, objmin, objmax, var):
        try:
            vars = self.data[self.chooseDataComboBox.currentText()].df[var].columns.values
            objmin.setValue(min(vars))
            objmax.setValue(max(vars))
        except Exception as e:
            print(e)

    def on_pushButton_clicked(self):
        filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None, "Save Plot", self.outpath, "(*.png)")
        self.plotFilenameLineEdit.setText(filename)
        if self.plotFilenameLineEdit.text() == "":
            self.plotFilenameLineEdit.setText("*.png")


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = PlotSpectra()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets
from sklearn.gaussian_process.gaussian_process import GaussianProcess

from point_spectra_gui.ui.GP import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, GaussianProcess, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.numOfComponenetsSpinBox.setValue(4)
        self.setComboBox(self.regrComboBox, self._regression_types)
        self.defaultComboItem(self.regrComboBox, self.regr)
        self.setComboBox(self.corrComboBox, self._correlation_types)
        self.defaultComboItem(self.corrComboBox, self.corr)
        self.setComboBox(self.storageModeComboBox, ['light', 'full'])
        self.defaultComboItem(self.storageModeComboBox, self.storage_mode)
        self.verboseCheckBox.setChecked(self.verbose)
        self.theta0DoubleSpinBox.setValue(self.theta0)
        self.setComboBox(self.optimizerComboBox, self._optimizer_types)
        self.defaultComboItem(self.optimizerComboBox, self.optimizer)
        self.randomStartSpinBox.setValue(self.random_start)
        self.normalizeCheckBox.setChecked(self.normalize)

    def function(self):
        params = {
            'reduce_dim': self.reductionMethodComboBox.currentText(),
            'n_components': self.numOfComponenetsSpinBox.value(),
            'regr': self.regrComboBox.currentText(),
            'corr': self.corrComboBox.currentText(),
            'storage_mode': self.storageModeComboBox.currentText(),
            'verbose': self.verboseCheckBox.isChecked(),
            'theta0': self.theta0DoubleSpinBox.value(),
            'normalize': self.normalizeCheckBox.isChecked(),
            'optimizer': self.optimizerComboBox.currentText(),
            'random_start': self.randomStartSpinBox.value(),
        }

        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.fit_interceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fit_interceptLabel.setObjectName("fit_interceptLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.fit_interceptLabel)
        self.fit_interceptCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fit_interceptCheckBox.setObjectName("fit_interceptCheckBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.fit_interceptCheckBox)
        self.verboseLabel = QtWidgets.QLabel(self.formGroupBox)
        self.verboseLabel.setObjectName("verboseLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.verboseLabel)
        self.verboseCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.verboseCheckBox.setObjectName("verboseCheckBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.verboseCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.precomputeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.precomputeLabel.setObjectName("precomputeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.precomputeLabel)
        self.precomputeComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.precomputeComboBox.setObjectName("precomputeComboBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.precomputeComboBox)
        self.n_nonzero_coefsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.n_nonzero_coefsLabel.setObjectName("n_nonzero_coefsLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.n_nonzero_coefsLabel)
        self.n_nonzero_coefsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.n_nonzero_coefsSpinBox.setObjectName("n_nonzero_coefsSpinBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.n_nonzero_coefsSpinBox)
        self.copy_XLabel = QtWidgets.QLabel(self.formGroupBox)
        self.copy_XLabel.setObjectName("copy_XLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.copy_XLabel)
        self.copy_XCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.copy_XCheckBox.setObjectName("copy_XCheckBox")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.copy_XCheckBox)
        self.fit_pathLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fit_pathLabel.setObjectName("fit_pathLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.fit_pathLabel)
        self.fit_pathCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fit_pathCheckBox.setObjectName("fit_pathCheckBox")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.fit_pathCheckBox)
        self.positiveLabel = QtWidgets.QLabel(self.formGroupBox)
        self.positiveLabel.setObjectName("positiveLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.positiveLabel)
        self.positiveCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.positiveCheckBox.setObjectName("positiveCheckBox")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.positiveCheckBox)
        self.max_iterLabel = QtWidgets.QLabel(self.formGroupBox)
        self.max_iterLabel.setObjectName("max_iterLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.max_iterLabel)
        self.max_iterSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.max_iterSpinBox.setEnabled(False)
        self.max_iterSpinBox.setObjectName("max_iterSpinBox")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.max_iterSpinBox)
        self.cvLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cvLabel.setObjectName("cvLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.cvLabel)
        self.cvSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.cvSpinBox.setEnabled(False)
        self.cvSpinBox.setProperty("value", 3)
        self.cvSpinBox.setObjectName("cvSpinBox")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.cvSpinBox)
        self.max_n_alphasLabel = QtWidgets.QLabel(self.formGroupBox)
        self.max_n_alphasLabel.setObjectName("max_n_alphasLabel")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.max_n_alphasLabel)
        self.max_n_alphasSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.max_n_alphasSpinBox.setEnabled(False)
        self.max_n_alphasSpinBox.setObjectName("max_n_alphasSpinBox")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.max_n_alphasSpinBox)
        self.n_jobsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.n_jobsLabel.setObjectName("n_jobsLabel")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.LabelRole, self.n_jobsLabel)
        self.n_jobsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.n_jobsSpinBox.setEnabled(False)
        self.n_jobsSpinBox.setObjectName("n_jobsSpinBox")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.FieldRole, self.n_jobsSpinBox)
        self.cVLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cVLabel.setObjectName("cVLabel")
        self.formLayout.setWidget(12, QtWidgets.QFormLayout.LabelRole, self.cVLabel)
        self.cVCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.cVCheckBox.setObjectName("cVCheckBox")
        self.formLayout.setWidget(12, QtWidgets.QFormLayout.FieldRole, self.cVCheckBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        self.cVCheckBox.toggled['bool'].connect(self.max_iterSpinBox.setEnabled)
        self.cVCheckBox.toggled['bool'].connect(self.cvSpinBox.setEnabled)
        self.cVCheckBox.toggled['bool'].connect(self.max_n_alphasSpinBox.setEnabled)
        self.cVCheckBox.toggled['bool'].connect(self.n_jobsSpinBox.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.fit_interceptLabel.setText(("fit_intercept"))
        self.verboseLabel.setText(("verbose"))
        self.normalizeLabel.setText(("normalize"))
        self.precomputeLabel.setText(("precompute"))
        self.n_nonzero_coefsLabel.setText(("n_nonzero_coefs"))
        self.copy_XLabel.setText(("copy_X"))
        self.fit_pathLabel.setText(("fit_path"))
        self.positiveLabel.setText(("positive"))
        self.max_iterLabel.setText(("max_iter"))
        self.cvLabel.setText(("cv"))
        self.max_n_alphasLabel.setText(("max_n_alphas"))
        self.n_jobsLabel.setText(("n_jobs"))
        self.cVLabel.setText(("Cross Validate"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets

from point_spectra_gui.ui.MaskData import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class MaskData(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def on_getDataButton_clicked(self, lineEdit):
        filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None, "Open Mask Data File", '.', "(*.csv)")
        lineEdit.setText(filename)
        if lineEdit.text() == "":
            lineEdit.setText("*.csv")

    def connectWidgets(self):
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.pushButton.clicked.connect(lambda: self.on_getDataButton_clicked(self.maskFileLineEdit))

    def function(self):
        datakey = self.chooseDataComboBox.currentText()
        maskfile = self.maskFileLineEdit.text()
        self.data[datakey].mask(maskfile, maskvar='wvl')
        print("Mask applied")


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = MaskData()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupLayout = QtWidgets.QGroupBox(Form)
        self.groupLayout.setObjectName("groupLayout")
        self.gridLayout = QtWidgets.QGridLayout(self.groupLayout)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupLayout)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.horizontalLayout_3.addWidget(self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupLayout)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.horizontalLayout_3.addWidget(self.chooseDataComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_3, 0, 0, 1, 1)
        self.xVariableLabel = QtWidgets.QLabel(self.groupLayout)
        self.xVariableLabel.setObjectName("xVariableLabel")
        self.gridLayout.addWidget(self.xVariableLabel, 1, 0, 1, 1)
        self.yVariableLabel = QtWidgets.QLabel(self.groupLayout)
        self.yVariableLabel.setObjectName("yVariableLabel")
        self.gridLayout.addWidget(self.yVariableLabel, 1, 1, 1, 1)
        self.xVariableList = QtWidgets.QListWidget(self.groupLayout)
        self.xVariableList.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.xVariableList.sizePolicy().hasHeightForWidth())
        self.xVariableList.setSizePolicy(sizePolicy)
        self.xVariableList.setObjectName("xVariableList")
        item = QtWidgets.QListWidgetItem()
        self.xVariableList.addItem(item)
        self.gridLayout.addWidget(self.xVariableList, 2, 0, 1, 1)
        self.yVariableList = QtWidgets.QListWidget(self.groupLayout)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.yVariableList.sizePolicy().hasHeightForWidth())
        self.yVariableList.setSizePolicy(sizePolicy)
        self.yVariableList.setObjectName("yVariableList")
        item = QtWidgets.QListWidgetItem()
        self.yVariableList.addItem(item)
        self.gridLayout.addWidget(self.yVariableList, 2, 1, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.chooseAlgorithmLabel = QtWidgets.QLabel(self.groupLayout)
        self.chooseAlgorithmLabel.setObjectName("chooseAlgorithmLabel")
        self.horizontalLayout_2.addWidget(self.chooseAlgorithmLabel)
        self.chooseAlgorithmComboBox = QtWidgets.QComboBox(self.groupLayout)
        self.chooseAlgorithmComboBox.setObjectName("chooseAlgorithmComboBox")
        self.horizontalLayout_2.addWidget(self.chooseAlgorithmComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_2, 3, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.yMinLabel = QtWidgets.QLabel(self.groupLayout)
        self.yMinLabel.setObjectName("yMinLabel")
        self.horizontalLayout.addWidget(self.yMinLabel)
        self.yMinDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupLayout)
        self.yMinDoubleSpinBox.setObjectName("yMinDoubleSpinBox")
        self.horizontalLayout.addWidget(self.yMinDoubleSpinBox)
        self.yMaxLabel = QtWidgets.QLabel(self.groupLayout)
        self.yMaxLabel.setObjectName("yMaxLabel")
        self.horizontalLayout.addWidget(self.yMaxLabel)
        self.yMaxDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupLayout)
        self.yMaxDoubleSpinBox.setObjectName("yMaxDoubleSpinBox")
        self.horizontalLayout.addWidget(self.yMaxDoubleSpinBox)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 1, 1, 1)
        self.algorithmLayout = QtWidgets.QVBoxLayout()
        self.algorithmLayout.setObjectName("algorithmLayout")
        self.gridLayout.addLayout(self.algorithmLayout, 4, 0, 1, 2)
        self.verticalLayout_2.addWidget(self.groupLayout)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupLayout.setTitle(("Cross Validation / Training"))
        self.chooseDataLabel.setText(("Choose Data"))
        self.xVariableLabel.setText(("X Variable"))
        self.yVariableLabel.setText(("Y Variable"))
        __sortingEnabled = self.xVariableList.isSortingEnabled()
        self.xVariableList.setSortingEnabled(False)
        item = self.xVariableList.item(0)
        item.setText(("Choose X"))
        self.xVariableList.setSortingEnabled(__sortingEnabled)
        self.yVariableList.setSortingEnabled(True)
        __sortingEnabled = self.yVariableList.isSortingEnabled()
        self.yVariableList.setSortingEnabled(False)
        item = self.yVariableList.item(0)
        item.setText(("Choose Y"))
        self.yVariableList.setSortingEnabled(__sortingEnabled)
        self.chooseAlgorithmLabel.setText(("Choose Algorithm"))
        self.yMinLabel.setText(("Y Min"))
        self.yMaxLabel.setText(("Y Max"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.linear_model.least_angle import Lars
from sklearn.linear_model.least_angle import LarsCV

from point_spectra_gui.ui.LARS import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        # LARS/         # LARSCV

        lars = Lars()
        larscv = LarsCV()
        self.fit_interceptCheckBox.setChecked(lars.fit_intercept)
        self.verboseCheckBox.setChecked(lars.verbose)
        self.normalizeCheckBox.setChecked(lars.normalize)
        self.setComboBox(self.precomputeComboBox, ['True', 'False', 'auto', 'array-like'])
        self.defaultComboItem(self.precomputeComboBox, lars.precompute)
        self.n_nonzero_coefsSpinBox.setValue(lars.n_nonzero_coefs)
        self.copy_XCheckBox.setChecked(lars.copy_X)
        self.fit_pathCheckBox.setChecked(lars.fit_path)
        self.positiveCheckBox.setChecked(lars.positive)
        self.max_iterSpinBox.setValue(larscv.max_iter)
        self.max_n_alphasSpinBox.setValue(larscv.max_n_alphas)
        self.n_jobsSpinBox.setValue(larscv.n_jobs)

    def function(self):
        if self.cVCheckBox.isChecked():
            params = {
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'positive': self.positiveCheckBox.isChecked(),
                'max_iter': self.max_iterSpinBox.value(),
                'verbose': self.verboseCheckBox.isChecked(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': self.precomputeComboBox.currentText(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'cv': self.cvSpinBox.value(),
                'max_n_alphas': self.max_n_alphasSpinBox.value(),
                'n_jobs': self.n_jobsSpinBox.value(),
                'CV': self.cVCheckBox.isChecked(),
            }
        else:
            params = {
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'verbose': self.verboseCheckBox.isChecked(),
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': {'True': True, 'False': False, 'auto': 'auto', 'array-like': 'array-like'}.get(
                    self.precomputeComboBox.currentText()),
                'n_nonzero_coefs': self.n_nonzero_coefsSpinBox.value(),
                'copy_X': self.copy_XCheckBox.isChecked(),
                'fit_path': self.fit_pathCheckBox.isChecked(),
                'positive': self.positiveCheckBox.isChecked(),
                'CV': self.cVCheckBox.isChecked(),
            }

        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



def del_layout(QLayout):
    to_delete = QLayout.takeAt(QLayout.count() - 1)  # remove the layout item at n-1 index
    if to_delete is not None:  # We run this method as long as there are objects
        while to_delete.count():  # while the count is not 0
            item = to_delete.takeAt(0)  # grab the layout item at 0th index
            widget = item.widget()  # get the widget at this location
            if widget is not None:  # if there is an object in this widget
                widget.deleteLater()  # delete this widget
            else:
                pass


def del_qwidget(QWidget):
    QWidget.close()
    QWidget.deleteLater()



from PyQt5 import QtWidgets
from sklearn.cross_decomposition.pls_ import PLSRegression

from point_spectra_gui.ui.PLS import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, PLSRegression, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.numOfComponentsLineEdit.setText(str(self.n_components))

    def function(self):
        nc = self.numOfComponentsLineEdit.text().split(',')
        nc = [int(i) for i in nc]
        print("PLS is using the first value")
        params = {'n_components': nc[0],
                  'scale': False}
        modelkey = '(nc=' + str(params['n_components']) + ')'
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.minSpinBox_4 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_4.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_4.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_4.setObjectName("minSpinBox_4")
        self.gridLayout_2.addWidget(self.minSpinBox_4, 5, 3, 1, 1)
        self.minLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_5.setObjectName("minLabel_5")
        self.gridLayout_2.addWidget(self.minLabel_5, 6, 2, 1, 1)
        self.lowModelMaxSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.lowModelMaxSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.lowModelMaxSpinBox.setMaximumSize(QtCore.QSize(910, 16777215))
        self.lowModelMaxSpinBox.setObjectName("lowModelMaxSpinBox")
        self.gridLayout_2.addWidget(self.lowModelMaxSpinBox, 1, 3, 1, 1)
        self.lowModelComboBox = QtWidgets.QComboBox(self.groupBox)
        self.lowModelComboBox.setObjectName("lowModelComboBox")
        self.gridLayout_2.addWidget(self.lowModelComboBox, 1, 1, 1, 1)
        self.maxSpinBox_4 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_4.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_4.setObjectName("maxSpinBox_4")
        self.gridLayout_2.addWidget(self.maxSpinBox_4, 5, 5, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.addSubModelPushButton = QtWidgets.QPushButton(self.groupBox)
        self.addSubModelPushButton.setObjectName("addSubModelPushButton")
        self.horizontalLayout.addWidget(self.addSubModelPushButton)
        self.deleteSubModelPushButton = QtWidgets.QPushButton(self.groupBox)
        self.deleteSubModelPushButton.setObjectName("deleteSubModelPushButton")
        self.horizontalLayout.addWidget(self.deleteSubModelPushButton)
        self.optimizeSubmodelRangesCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.optimizeSubmodelRangesCheckBox.setObjectName("optimizeSubmodelRangesCheckBox")
        self.horizontalLayout.addWidget(self.optimizeSubmodelRangesCheckBox)
        self.gridLayout_2.addLayout(self.horizontalLayout, 18, 0, 1, 6)
        self.maxSpinBox_3 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_3.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_3.setObjectName("maxSpinBox_3")
        self.gridLayout_2.addWidget(self.maxSpinBox_3, 4, 5, 1, 1)
        self.minSpinBox_3 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_3.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_3.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_3.setObjectName("minSpinBox_3")
        self.gridLayout_2.addWidget(self.minSpinBox_3, 4, 3, 1, 1)
        self.maxLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_4.setObjectName("maxLabel_4")
        self.gridLayout_2.addWidget(self.maxLabel_4, 5, 4, 1, 1)
        self.referenceModelLabel = QtWidgets.QLabel(self.groupBox)
        self.referenceModelLabel.setObjectName("referenceModelLabel")
        self.gridLayout_2.addWidget(self.referenceModelLabel, 0, 0, 1, 1)
        self.lowModelMaxLabel = QtWidgets.QLabel(self.groupBox)
        self.lowModelMaxLabel.setMaximumSize(QtCore.QSize(30, 16777215))
        self.lowModelMaxLabel.setObjectName("lowModelMaxLabel")
        self.gridLayout_2.addWidget(self.lowModelMaxLabel, 1, 2, 1, 1)
        self.modelComboBox_5 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_5.setObjectName("modelComboBox_5")
        self.gridLayout_2.addWidget(self.modelComboBox_5, 6, 1, 1, 1)
        self.minLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_3.setObjectName("minLabel_3")
        self.gridLayout_2.addWidget(self.minLabel_3, 4, 2, 1, 1)
        self.modelComboBox_4 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_4.setObjectName("modelComboBox_4")
        self.gridLayout_2.addWidget(self.modelComboBox_4, 5, 1, 1, 1)
        self.modelComboBox_3 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_3.setObjectName("modelComboBox_3")
        self.gridLayout_2.addWidget(self.modelComboBox_3, 4, 1, 1, 1)
        self.modelComboBox = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox.setObjectName("modelComboBox")
        self.gridLayout_2.addWidget(self.modelComboBox, 2, 1, 1, 1)
        self.minLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_8.setObjectName("minLabel_8")
        self.gridLayout_2.addWidget(self.minLabel_8, 9, 2, 1, 1)
        self.minSpinBox_5 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_5.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_5.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_5.setObjectName("minSpinBox_5")
        self.gridLayout_2.addWidget(self.minSpinBox_5, 6, 3, 1, 1)
        self.minSpinBox_8 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_8.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_8.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_8.setObjectName("minSpinBox_8")
        self.gridLayout_2.addWidget(self.minSpinBox_8, 9, 3, 1, 1)
        self.maxSpinBox_2 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_2.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_2.setObjectName("maxSpinBox_2")
        self.gridLayout_2.addWidget(self.maxSpinBox_2, 3, 5, 1, 1)
        self.maxLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_2.setObjectName("maxLabel_2")
        self.gridLayout_2.addWidget(self.maxLabel_2, 3, 4, 1, 1)
        self.maxLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_5.setObjectName("maxLabel_5")
        self.gridLayout_2.addWidget(self.maxLabel_5, 6, 4, 1, 1)
        self.minLabel = QtWidgets.QLabel(self.groupBox)
        self.minLabel.setObjectName("minLabel")
        self.gridLayout_2.addWidget(self.minLabel, 2, 2, 1, 1)
        self.minLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_6.setObjectName("minLabel_6")
        self.gridLayout_2.addWidget(self.minLabel_6, 7, 2, 1, 1)
        self.maxLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_6.setObjectName("maxLabel_6")
        self.gridLayout_2.addWidget(self.maxLabel_6, 7, 4, 1, 1)
        self.minSpinBox_6 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_6.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_6.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_6.setObjectName("minSpinBox_6")
        self.gridLayout_2.addWidget(self.minSpinBox_6, 7, 3, 1, 1)
        self.maxLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_11.setObjectName("maxLabel_11")
        self.gridLayout_2.addWidget(self.maxLabel_11, 12, 4, 1, 1)
        self.maxSpinBox_8 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_8.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_8.setObjectName("maxSpinBox_8")
        self.gridLayout_2.addWidget(self.maxSpinBox_8, 9, 5, 1, 1)
        self.modelComboBox_9 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_9.setObjectName("modelComboBox_9")
        self.gridLayout_2.addWidget(self.modelComboBox_9, 10, 1, 1, 1)
        self.modelComboBox_2 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_2.setObjectName("modelComboBox_2")
        self.gridLayout_2.addWidget(self.modelComboBox_2, 3, 1, 1, 1)
        self.minSpinBox_2 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_2.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_2.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_2.setObjectName("minSpinBox_2")
        self.gridLayout_2.addWidget(self.minSpinBox_2, 3, 3, 1, 1)
        self.minSpinBox_9 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_9.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_9.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_9.setObjectName("minSpinBox_9")
        self.gridLayout_2.addWidget(self.minSpinBox_9, 10, 3, 1, 1)
        self.minSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox.setObjectName("minSpinBox")
        self.gridLayout_2.addWidget(self.minSpinBox, 2, 3, 1, 1)
        self.minLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_2.setObjectName("minLabel_2")
        self.gridLayout_2.addWidget(self.minLabel_2, 3, 2, 1, 1)
        self.maxSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox.setObjectName("maxSpinBox")
        self.gridLayout_2.addWidget(self.maxSpinBox, 2, 5, 1, 1)
        self.minLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_4.setObjectName("minLabel_4")
        self.gridLayout_2.addWidget(self.minLabel_4, 5, 2, 1, 1)
        self.maxSpinBox_5 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_5.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_5.setObjectName("maxSpinBox_5")
        self.gridLayout_2.addWidget(self.maxSpinBox_5, 6, 5, 1, 1)
        self.minSpinBox_11 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_11.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_11.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_11.setObjectName("minSpinBox_11")
        self.gridLayout_2.addWidget(self.minSpinBox_11, 12, 3, 1, 1)
        self.minLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_11.setObjectName("minLabel_11")
        self.gridLayout_2.addWidget(self.minLabel_11, 12, 2, 1, 1)
        self.referenceModelComboBox = QtWidgets.QComboBox(self.groupBox)
        self.referenceModelComboBox.setObjectName("referenceModelComboBox")
        self.gridLayout_2.addWidget(self.referenceModelComboBox, 0, 1, 1, 1)
        self.lowModelLabel = QtWidgets.QLabel(self.groupBox)
        self.lowModelLabel.setObjectName("lowModelLabel")
        self.gridLayout_2.addWidget(self.lowModelLabel, 1, 0, 1, 1)
        self.maxLabel = QtWidgets.QLabel(self.groupBox)
        self.maxLabel.setMaximumSize(QtCore.QSize(30, 16777215))
        self.maxLabel.setObjectName("maxLabel")
        self.gridLayout_2.addWidget(self.maxLabel, 2, 4, 1, 1)
        self.modelComboBox_6 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_6.setObjectName("modelComboBox_6")
        self.gridLayout_2.addWidget(self.modelComboBox_6, 7, 1, 1, 1)
        self.minLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_9.setObjectName("minLabel_9")
        self.gridLayout_2.addWidget(self.minLabel_9, 10, 2, 1, 1)
        self.maxLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_3.setObjectName("maxLabel_3")
        self.gridLayout_2.addWidget(self.maxLabel_3, 4, 4, 1, 1)
        self.modelComboBox_7 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_7.setObjectName("modelComboBox_7")
        self.gridLayout_2.addWidget(self.modelComboBox_7, 8, 1, 1, 1)
        self.minSpinBox_12 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_12.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_12.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_12.setObjectName("minSpinBox_12")
        self.gridLayout_2.addWidget(self.minSpinBox_12, 13, 3, 1, 1)
        self.minLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_12.setObjectName("minLabel_12")
        self.gridLayout_2.addWidget(self.minLabel_12, 13, 2, 1, 1)
        self.minLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_15.setObjectName("minLabel_15")
        self.gridLayout_2.addWidget(self.minLabel_15, 16, 2, 1, 1)
        self.maxSpinBox_11 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_11.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_11.setObjectName("maxSpinBox_11")
        self.gridLayout_2.addWidget(self.maxSpinBox_11, 12, 5, 1, 1)
        self.maxLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_9.setObjectName("maxLabel_9")
        self.gridLayout_2.addWidget(self.maxLabel_9, 10, 4, 1, 1)
        self.minSpinBox_7 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_7.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_7.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_7.setObjectName("minSpinBox_7")
        self.gridLayout_2.addWidget(self.minSpinBox_7, 8, 3, 1, 1)
        self.modelComboBox_8 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_8.setObjectName("modelComboBox_8")
        self.gridLayout_2.addWidget(self.modelComboBox_8, 9, 1, 1, 1)
        self.maxSpinBox_9 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_9.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_9.setObjectName("maxSpinBox_9")
        self.gridLayout_2.addWidget(self.maxSpinBox_9, 10, 5, 1, 1)
        self.highModelMinLabel = QtWidgets.QLabel(self.groupBox)
        self.highModelMinLabel.setObjectName("highModelMinLabel")
        self.gridLayout_2.addWidget(self.highModelMinLabel, 17, 2, 1, 1)
        self.modelComboBox_10 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_10.setObjectName("modelComboBox_10")
        self.gridLayout_2.addWidget(self.modelComboBox_10, 11, 1, 1, 1)
        self.maxSpinBox_14 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_14.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_14.setObjectName("maxSpinBox_14")
        self.gridLayout_2.addWidget(self.maxSpinBox_14, 15, 5, 1, 1)
        self.minSpinBox_15 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_15.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_15.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_15.setObjectName("minSpinBox_15")
        self.gridLayout_2.addWidget(self.minSpinBox_15, 16, 3, 1, 1)
        self.highModelLabel = QtWidgets.QLabel(self.groupBox)
        self.highModelLabel.setObjectName("highModelLabel")
        self.gridLayout_2.addWidget(self.highModelLabel, 17, 0, 1, 1)
        self.maxLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_15.setObjectName("maxLabel_15")
        self.gridLayout_2.addWidget(self.maxLabel_15, 16, 4, 1, 1)
        self.minLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_10.setObjectName("minLabel_10")
        self.gridLayout_2.addWidget(self.minLabel_10, 11, 2, 1, 1)
        self.minLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_7.setObjectName("minLabel_7")
        self.gridLayout_2.addWidget(self.minLabel_7, 8, 2, 1, 1)
        self.modelComboBox_12 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_12.setObjectName("modelComboBox_12")
        self.gridLayout_2.addWidget(self.modelComboBox_12, 13, 1, 1, 1)
        self.modelComboBox_15 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_15.setObjectName("modelComboBox_15")
        self.gridLayout_2.addWidget(self.modelComboBox_15, 16, 1, 1, 1)
        self.maxSpinBox_12 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_12.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_12.setObjectName("maxSpinBox_12")
        self.gridLayout_2.addWidget(self.maxSpinBox_12, 13, 5, 1, 1)
        self.highModelMinSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.highModelMinSpinBox.setMinimumSize(QtCore.QSize(130, 0))
        self.highModelMinSpinBox.setMaximumSize(QtCore.QSize(70, 16777215))
        self.highModelMinSpinBox.setObjectName("highModelMinSpinBox")
        self.gridLayout_2.addWidget(self.highModelMinSpinBox, 17, 3, 1, 1)
        self.minSpinBox_10 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_10.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_10.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_10.setObjectName("minSpinBox_10")
        self.gridLayout_2.addWidget(self.minSpinBox_10, 11, 3, 1, 1)
        self.maxLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_10.setObjectName("maxLabel_10")
        self.gridLayout_2.addWidget(self.maxLabel_10, 11, 4, 1, 1)
        self.maxSpinBox_6 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_6.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_6.setObjectName("maxSpinBox_6")
        self.gridLayout_2.addWidget(self.maxSpinBox_6, 7, 5, 1, 1)
        self.maxLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_8.setObjectName("maxLabel_8")
        self.gridLayout_2.addWidget(self.maxLabel_8, 9, 4, 1, 1)
        self.maxSpinBox_10 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_10.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_10.setObjectName("maxSpinBox_10")
        self.gridLayout_2.addWidget(self.maxSpinBox_10, 11, 5, 1, 1)
        self.maxSpinBox_7 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_7.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_7.setObjectName("maxSpinBox_7")
        self.gridLayout_2.addWidget(self.maxSpinBox_7, 8, 5, 1, 1)
        self.maxLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_7.setObjectName("maxLabel_7")
        self.gridLayout_2.addWidget(self.maxLabel_7, 8, 4, 1, 1)
        self.highModelComboBox = QtWidgets.QComboBox(self.groupBox)
        self.highModelComboBox.setObjectName("highModelComboBox")
        self.gridLayout_2.addWidget(self.highModelComboBox, 17, 1, 1, 1)
        self.maxSpinBox_15 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_15.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_15.setObjectName("maxSpinBox_15")
        self.gridLayout_2.addWidget(self.maxSpinBox_15, 16, 5, 1, 1)
        self.modelComboBox_11 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_11.setObjectName("modelComboBox_11")
        self.gridLayout_2.addWidget(self.modelComboBox_11, 12, 1, 1, 1)
        self.maxLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_14.setObjectName("maxLabel_14")
        self.gridLayout_2.addWidget(self.maxLabel_14, 15, 4, 1, 1)
        self.modelComboBox_13 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_13.setObjectName("modelComboBox_13")
        self.gridLayout_2.addWidget(self.modelComboBox_13, 14, 1, 1, 1)
        self.modelComboBox_14 = QtWidgets.QComboBox(self.groupBox)
        self.modelComboBox_14.setObjectName("modelComboBox_14")
        self.gridLayout_2.addWidget(self.modelComboBox_14, 15, 1, 1, 1)
        self.minLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_14.setObjectName("minLabel_14")
        self.gridLayout_2.addWidget(self.minLabel_14, 15, 2, 1, 1)
        self.minLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.minLabel_13.setObjectName("minLabel_13")
        self.gridLayout_2.addWidget(self.minLabel_13, 14, 2, 1, 1)
        self.maxLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_13.setObjectName("maxLabel_13")
        self.gridLayout_2.addWidget(self.maxLabel_13, 14, 4, 1, 1)
        self.minSpinBox_13 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_13.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_13.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_13.setObjectName("minSpinBox_13")
        self.gridLayout_2.addWidget(self.minSpinBox_13, 14, 3, 1, 1)
        self.maxSpinBox_13 = QtWidgets.QSpinBox(self.groupBox)
        self.maxSpinBox_13.setMinimumSize(QtCore.QSize(130, 0))
        self.maxSpinBox_13.setObjectName("maxSpinBox_13")
        self.gridLayout_2.addWidget(self.maxSpinBox_13, 14, 5, 1, 1)
        self.minSpinBox_14 = QtWidgets.QSpinBox(self.groupBox)
        self.minSpinBox_14.setMinimumSize(QtCore.QSize(130, 0))
        self.minSpinBox_14.setMaximumSize(QtCore.QSize(70, 16777215))
        self.minSpinBox_14.setObjectName("minSpinBox_14")
        self.gridLayout_2.addWidget(self.minSpinBox_14, 15, 3, 1, 1)
        self.maxLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.maxLabel_12.setObjectName("maxLabel_12")
        self.gridLayout_2.addWidget(self.maxLabel_12, 13, 4, 1, 1)
        self.formLayout_3 = QtWidgets.QFormLayout()
        self.formLayout_3.setObjectName("formLayout_3")
        self.optimizeSubmodelRangesLabel = QtWidgets.QLabel(self.groupBox)
        self.optimizeSubmodelRangesLabel.setObjectName("optimizeSubmodelRangesLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.optimizeSubmodelRangesLabel)
        self.optimizeSubmodelRangesComboBox = QtWidgets.QComboBox(self.groupBox)
        self.optimizeSubmodelRangesComboBox.setObjectName("optimizeSubmodelRangesComboBox")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.optimizeSubmodelRangesComboBox)
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.chooseDataComboBox)
        self.gridLayout_2.addLayout(self.formLayout_3, 19, 0, 1, 6)
        self.gridLayout.addWidget(self.groupBox, 0, 0, 1, 1)

        self.retranslateUi(Form)
        self.optimizeSubmodelRangesCheckBox.toggled['bool'].connect(self.optimizeSubmodelRangesComboBox.setVisible)
        self.optimizeSubmodelRangesCheckBox.toggled['bool'].connect(self.optimizeSubmodelRangesLabel.setVisible)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.referenceModelComboBox, self.lowModelComboBox)
        Form.setTabOrder(self.lowModelComboBox, self.lowModelMaxSpinBox)
        Form.setTabOrder(self.lowModelMaxSpinBox, self.modelComboBox)
        Form.setTabOrder(self.modelComboBox, self.minSpinBox)
        Form.setTabOrder(self.minSpinBox, self.maxSpinBox)
        Form.setTabOrder(self.maxSpinBox, self.modelComboBox_2)
        Form.setTabOrder(self.modelComboBox_2, self.minSpinBox_2)
        Form.setTabOrder(self.minSpinBox_2, self.maxSpinBox_2)
        Form.setTabOrder(self.maxSpinBox_2, self.modelComboBox_3)
        Form.setTabOrder(self.modelComboBox_3, self.minSpinBox_3)
        Form.setTabOrder(self.minSpinBox_3, self.maxSpinBox_3)
        Form.setTabOrder(self.maxSpinBox_3, self.modelComboBox_4)
        Form.setTabOrder(self.modelComboBox_4, self.minSpinBox_4)
        Form.setTabOrder(self.minSpinBox_4, self.maxSpinBox_4)
        Form.setTabOrder(self.maxSpinBox_4, self.modelComboBox_5)
        Form.setTabOrder(self.modelComboBox_5, self.minSpinBox_5)
        Form.setTabOrder(self.minSpinBox_5, self.maxSpinBox_5)
        Form.setTabOrder(self.maxSpinBox_5, self.modelComboBox_6)
        Form.setTabOrder(self.modelComboBox_6, self.minSpinBox_6)
        Form.setTabOrder(self.minSpinBox_6, self.maxSpinBox_6)
        Form.setTabOrder(self.maxSpinBox_6, self.modelComboBox_7)
        Form.setTabOrder(self.modelComboBox_7, self.minSpinBox_7)
        Form.setTabOrder(self.minSpinBox_7, self.maxSpinBox_7)
        Form.setTabOrder(self.maxSpinBox_7, self.modelComboBox_8)
        Form.setTabOrder(self.modelComboBox_8, self.minSpinBox_8)
        Form.setTabOrder(self.minSpinBox_8, self.maxSpinBox_8)
        Form.setTabOrder(self.maxSpinBox_8, self.modelComboBox_9)
        Form.setTabOrder(self.modelComboBox_9, self.minSpinBox_9)
        Form.setTabOrder(self.minSpinBox_9, self.maxSpinBox_9)
        Form.setTabOrder(self.maxSpinBox_9, self.modelComboBox_10)
        Form.setTabOrder(self.modelComboBox_10, self.minSpinBox_10)
        Form.setTabOrder(self.minSpinBox_10, self.maxSpinBox_10)
        Form.setTabOrder(self.maxSpinBox_10, self.modelComboBox_11)
        Form.setTabOrder(self.modelComboBox_11, self.minSpinBox_11)
        Form.setTabOrder(self.minSpinBox_11, self.maxSpinBox_11)
        Form.setTabOrder(self.maxSpinBox_11, self.modelComboBox_12)
        Form.setTabOrder(self.modelComboBox_12, self.minSpinBox_12)
        Form.setTabOrder(self.minSpinBox_12, self.maxSpinBox_12)
        Form.setTabOrder(self.maxSpinBox_12, self.modelComboBox_13)
        Form.setTabOrder(self.modelComboBox_13, self.minSpinBox_13)
        Form.setTabOrder(self.minSpinBox_13, self.maxSpinBox_13)
        Form.setTabOrder(self.maxSpinBox_13, self.modelComboBox_14)
        Form.setTabOrder(self.modelComboBox_14, self.minSpinBox_14)
        Form.setTabOrder(self.minSpinBox_14, self.maxSpinBox_14)
        Form.setTabOrder(self.maxSpinBox_14, self.modelComboBox_15)
        Form.setTabOrder(self.modelComboBox_15, self.minSpinBox_15)
        Form.setTabOrder(self.minSpinBox_15, self.maxSpinBox_15)
        Form.setTabOrder(self.maxSpinBox_15, self.highModelComboBox)
        Form.setTabOrder(self.highModelComboBox, self.highModelMinSpinBox)
        Form.setTabOrder(self.highModelMinSpinBox, self.addSubModelPushButton)
        Form.setTabOrder(self.addSubModelPushButton, self.deleteSubModelPushButton)
        Form.setTabOrder(self.deleteSubModelPushButton, self.optimizeSubmodelRangesCheckBox)
        Form.setTabOrder(self.optimizeSubmodelRangesCheckBox, self.optimizeSubmodelRangesComboBox)
        Form.setTabOrder(self.optimizeSubmodelRangesComboBox, self.chooseDataComboBox)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Submodel - Predict"))
        self.minLabel_5.setText(("Min"))
        self.addSubModelPushButton.setText(("Add submodel"))
        self.deleteSubModelPushButton.setText(("Delete submodel"))
        self.optimizeSubmodelRangesCheckBox.setText(("Optimize "))
        self.maxLabel_4.setText(("Max"))
        self.referenceModelLabel.setText(("Choose reference model: "))
        self.lowModelMaxLabel.setText(("Max"))
        self.minLabel_3.setText(("Min"))
        self.minLabel_8.setText(("Min"))
        self.maxLabel_2.setText(("Max"))
        self.maxLabel_5.setText(("Max"))
        self.minLabel.setText(("Min"))
        self.minLabel_6.setText(("Min"))
        self.maxLabel_6.setText(("Max"))
        self.maxLabel_11.setText(("Max"))
        self.minLabel_2.setText(("Min"))
        self.minLabel_4.setText(("Min"))
        self.minLabel_11.setText(("Min"))
        self.lowModelLabel.setText(("Low Model"))
        self.maxLabel.setText(("Max"))
        self.minLabel_9.setText(("Min"))
        self.maxLabel_3.setText(("Max"))
        self.minLabel_12.setText(("Min"))
        self.minLabel_15.setText(("Min"))
        self.maxLabel_9.setText(("Max"))
        self.highModelMinLabel.setText(("Min"))
        self.highModelLabel.setText(("High Model"))
        self.maxLabel_15.setText(("Max"))
        self.minLabel_10.setText(("Min"))
        self.minLabel_7.setText(("Min"))
        self.maxLabel_10.setText(("Max"))
        self.maxLabel_8.setText(("Max"))
        self.maxLabel_7.setText(("Max"))
        self.maxLabel_14.setText(("Max"))
        self.minLabel_14.setText(("Min"))
        self.minLabel_13.setText(("Min"))
        self.maxLabel_13.setText(("Max"))
        self.maxLabel_12.setText(("Max"))
        self.optimizeSubmodelRangesLabel.setText(("Choose known data to optimize submodel ranges:"))
        self.chooseDataLabel.setText(("Choose data to predict"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setObjectName("formLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseDataComboBox)
        self.chooseMethodLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseMethodLabel.setObjectName("chooseMethodLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.chooseMethodLabel)
        self.chooseMethodComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseMethodComboBox.setObjectName("chooseMethodComboBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.chooseMethodComboBox)
        self.dim_reduction_vlayout = QtWidgets.QVBoxLayout()
        self.dim_reduction_vlayout.setObjectName("dim_reduction_vlayout")
        self.formLayout.setLayout(2, QtWidgets.QFormLayout.SpanningRole, self.dim_reduction_vlayout)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("Dimensionality Reduction"))
        self.chooseDataLabel.setText(("Choose data:"))
        self.chooseMethodLabel.setText(("Choose method:"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupbox = QtWidgets.QGroupBox(Form)
        self.groupbox.setObjectName("groupbox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupbox)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.orderLabel = QtWidgets.QLabel(self.groupbox)
        self.orderLabel.setObjectName("orderLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.orderLabel)
        self.orderSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.orderSpinBox.setObjectName("orderSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.orderSpinBox)
        self.numOfStandardDeviationsLabel = QtWidgets.QLabel(self.groupbox)
        self.numOfStandardDeviationsLabel.setObjectName("numOfStandardDeviationsLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.numOfStandardDeviationsLabel)
        self.numOfStandardDeviationsSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.numOfStandardDeviationsSpinBox.setObjectName("numOfStandardDeviationsSpinBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.numOfStandardDeviationsSpinBox)
        self.maxNumOfIterationsLabel = QtWidgets.QLabel(self.groupbox)
        self.maxNumOfIterationsLabel.setObjectName("maxNumOfIterationsLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.maxNumOfIterationsLabel)
        self.maxNumOfIterationsSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.maxNumOfIterationsSpinBox.setObjectName("maxNumOfIterationsSpinBox")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.maxNumOfIterationsSpinBox)
        self.verticalLayout.addWidget(self.groupbox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.orderLabel.setText(("Order"))
        self.numOfStandardDeviationsLabel.setText(("Num of Standard Deviations"))
        self.maxNumOfIterationsLabel.setText(("Max Num of Iterations"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets

from point_spectra_gui.ui.DimensionalityReduction import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class DimensionalityReduction(Ui_Form, Basics):
    _methods = [
        'PCA',
        'FastICA'#,
        #'ICA-JADE',
    ]

    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseMethodComboBox, ['Choose a method'] + self._methods)
        self.chooseMethodComboBox.currentIndexChanged.connect(
            lambda: self.method_ComboBox_IndexChanged(self.chooseMethodComboBox.currentText()))

    def function(self):
        col = 'wvl'
        self.dim_reds = {}
        self.dim_red_keys = []
        load_fit = None
        dim_red_key = None
        datakey = self.chooseDataComboBox.currentText()
        method = self.chooseMethodComboBox.currentText()
        params = []
        method_kws = {}
        try:
            if method == 'PCA':
                method_kws = {'n_components': self.dim_red_widget.pca_nc_spinbox.value()}

            if method == 'FastICA':
                method_kws = {'n_components': self.dim_red_widget.ica_nc_spinbox.value()}

            if method == 'ICA-JADE':
                method_kws = {'n_components': self.dim_red_widget.ica_jade_nc_spinbox.value()}

        except Exception as e:
            print(e)

        try:
            if method == 'PCA' or method == 'FastICA':
                self.dim_reds[dim_red_key] = self.data[datakey].dim_red(
                    col, method, params, method_kws, load_fit=load_fit)
            elif method == 'ICA-JADE':
                self.dim_reds[dim_red_key] = self.data[datakey].ica_jade(col)
            self.dim_red_keys.append(dim_red_key)

        except Exception as e:
            print(e)

    def method_ComboBox_IndexChanged(self, method):
        print(method)
        try:
            self.dim_red_widget.deleteLater()
        except:
            pass
        self.dim_red_widget = QtWidgets.QWidget()
        if method == 'PCA':
            self.dim_red_widget.pca_hlayout = QtWidgets.QHBoxLayout(self.dim_red_widget)
            self.dim_red_widget.pca_nc_label = QtWidgets.QLabel(self.dim_red_widget)
            self.dim_red_widget.pca_nc_label.setText('# of components:')
            self.dim_red_widget.pca_nc_label.setObjectName("self.pca_nc_label")
            self.dim_red_widget.pca_hlayout.addWidget(self.dim_red_widget.pca_nc_label)
            self.dim_red_widget.pca_nc_spinbox = QtWidgets.QSpinBox(self.dim_red_widget)

            self.dim_red_widget.pca_nc_spinbox.setObjectName("self.pca_nc_spinbox")
            self.dim_red_widget.pca_hlayout.addWidget(self.dim_red_widget.pca_nc_spinbox)
            self.dim_red_widget.pca_spacer = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding,
                                                                   QtWidgets.QSizePolicy.Minimum)
            self.dim_red_widget.pca_hlayout.addItem(self.dim_red_widget.pca_spacer)
            self.dim_red_widget.pca_nc_spinbox.setValue(2)

        if method == 'FastICA':
            self.dim_red_widget.ica_hlayout = QtWidgets.QHBoxLayout(self.dim_red_widget)
            self.dim_red_widget.ica_nc_label = QtWidgets.QLabel(self.dim_red_widget)
            self.dim_red_widget.ica_nc_label.setText('# of components:')
            self.dim_red_widget.ica_nc_label.setObjectName("self.ica_nc_label")
            self.dim_red_widget.ica_hlayout.addWidget(self.dim_red_widget.ica_nc_label)
            self.dim_red_widget.ica_nc_spinbox = QtWidgets.QSpinBox(self.dim_red_widget)
            self.dim_red_widget.ica_nc_spinbox.setObjectName("self.ica_nc_spinbox")
            self.dim_red_widget.ica_hlayout.addWidget(self.dim_red_widget.ica_nc_spinbox)
            self.dim_red_widget.ica_spacer = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding,
                                                                   QtWidgets.QSizePolicy.Minimum)
            self.dim_red_widget.ica_hlayout.addItem(self.dim_red_widget.ica_spacer)
            self.dim_red_widget.ica_nc_spinbox.setValue(2)

        if method == 'ICA-JADE':
            self.dim_red_widget.ica_jade_hlayout = QtWidgets.QHBoxLayout(self.dim_red_widget)
            self.dim_red_widget.ica_jade_nc_label = QtWidgets.QLabel(self.dim_red_widget)
            self.dim_red_widget.ica_jade_nc_label.setText('# of components:')
            self.dim_red_widget.ica_jade_nc_label.setObjectName("self.ica_jade_nc_label")
            self.dim_red_widget.ica_jade_hlayout.addWidget(self.dim_red_widget.ica_jade_nc_label)
            self.dim_red_widget.ica_jade_nc_spinbox = QtWidgets.QSpinBox(self.dim_red_widget)
            self.dim_red_widget.ica_jade_nc_spinbox.setObjectName("self.ica_jade_nc_spinbox")
            self.dim_red_widget.ica_jade_hlayout.addWidget(self.dim_red_widget.ica_jade_nc_spinbox)
            self.dim_red_widget.ica_jade_spacer = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding,
                                                                        QtWidgets.QSizePolicy.Minimum)
            self.dim_red_widget.ica_jade_hlayout.addItem(self.dim_red_widget.ica_jade_spacer)
            self.dim_red_widget.ica_jade_nc_spinbox.setValue(2)

            self.dim_red_widget.setObjectName("dim_red_widget")
        self.dim_reduction_vlayout.addWidget(self.dim_red_widget)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = DimensionalityReduction()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.ui.RegressionPredict import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class RegressionPredict(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataComboBox, self.data)
        self.setComboBox(self.chooseModelComboBox, self.modelkeys)

    def function(self):
        datakey = self.chooseDataComboBox.currentText()
        modelkey = self.chooseModelComboBox.currentText()
        predictname = ('predict', modelkey + ' - ' + datakey + ' - Predict')

        try:
            prediction = self.models[modelkey].predict(self.data[datakey].df[self.model_xvars[modelkey]])
            self.data[datakey].df[predictname] = prediction
            pass
        except Exception as e:
            print(e)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = RegressionPredict()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())
